# OrgScopePatchDocument

An Org scoped Patch based on RFC 6902
## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**updated** | **datetime** | Update time | [optional] [readonly] 
**org_id** | **str** | Organisation Id  | 
**patches** | **list[object]** | A list of PatchDocument  | 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


